@@ -154,9 +154,9 @@ static void mm_sync_vvm_imap_server (void);
 static void vvmd_connect_to_sms_wap (void);
 static void vvmd_disconnect_from_sms_wap (void);
 static void vvmd_get_all_sms (void);
-static void vvmd_unsubscribe_service (void);
-static void vvmd_check_subscription_status (void);
-static void vvmd_subscribe_service (void);
+static gboolean vvmd_unsubscribe_service (gpointer user_data);
+static gboolean vvmd_check_subscription_status (gpointer user_data);
+static gboolean vvmd_subscribe_service (gpointer user_data);
 
 static void
 handle_method_call (GDBusConnection       *connection,
@@ -269,13 +269,13 @@ handle_method_call (GDBusConnection       *connection,
 
           if (modem->enable_vvm == FALSE && VVMStatus == TRUE)
             {
-              DBG ("Subscribing from VVM");
-              vvmd_subscribe_service ();
+              DBG ("Subscribing to VVM");
+              vvmd_subscribe_service (NULL);
             }
           else if (modem->enable_vvm == TRUE && VVMStatus == FALSE)
             {
               DBG ("Unsubscribing from VVM");
-              vvmd_unsubscribe_service ();
+              vvmd_unsubscribe_service (NULL);
             }
           else
             DBG ("VVM status Unchanged!");
@@ -411,7 +411,7 @@ handle_method_call (GDBusConnection       *connection,
   else if (g_strcmp0 (method_name, "CheckSubscriptonStatus") == 0)
     {
       DBG ("Checking Subscription Status.");
-      vvmd_check_subscription_status ();
+      vvmd_check_subscription_status (NULL);
       g_dbus_method_invocation_return_value (invocation, NULL);
     }
 }
@@ -559,7 +559,7 @@ vvm_process_status_message (struct sms_control_message *sms_msg)
 
       if (modem->enable_vvm)
         {
-          vvmd_subscribe_service ();
+          vvmd_subscribe_service (NULL);
           DBG ("Subscribing to your carrier's VVM service");
         }
     }
@@ -569,7 +569,7 @@ vvm_process_status_message (struct sms_control_message *sms_msg)
       if (!modem->enable_vvm)
         {
           DBG ("Unsubscribing from your carrier's VVM service");
-          vvmd_unsubscribe_service ();
+          vvmd_unsubscribe_service (NULL);
         }
       else {
           /*
@@ -1255,7 +1255,7 @@ vvmd_mm_get_modem_state (void)
                 DBG ("VVM is not enabled!");
                 return;
               }
-            vvmd_check_subscription_status ();
+            vvmd_check_subscription_status (NULL);
             return;
           }
     }
@@ -1449,23 +1449,24 @@ vvmd_mm_create_sms (const gchar *message)
 }
 
 
-static void
-vvmd_subscribe_service (void)
+static gboolean
+vvmd_subscribe_service (gpointer user_data)
 {
   g_autofree char *message = NULL;
 
+  DBG ("Subscribing to your carrier's VVM service");
   if (modem->provision_status == VVM_PROVISION_STATUS_NOT_SET)
     {
       DBG ("Your provisioning status is unknown");
       DBG ("Checking Subscription Status");
-      vvmd_check_subscription_status ();
-      return;
+      vvmd_check_subscription_status (NULL);
+      return G_SOURCE_REMOVE;
     }
   else if (g_strcmp0 (modem->vvm_type, "vvm3") == 0)
     {
       DBG ("Checking vvm3 subscription status");
-      vvmd_check_subscription_status ();
-      return;
+      vvmd_check_subscription_status (NULL);
+      return G_SOURCE_REMOVE;
     }
   else
     DBG ("You are not be subscribed to your carrier's VVM service");
@@ -1473,13 +1474,13 @@ vvmd_subscribe_service (void)
   if (modem->modem_available == FALSE)
     {
       DBG ("Modem not available");
-      return;
+      return G_SOURCE_REMOVE;
     }
 
   if (modem->modem_ready == FALSE)
     {
       DBG ("Modem not ready");
-      return;
+      return G_SOURCE_REMOVE;
     }
 
   message = vvm_util_create_activate_sms (modem->carrier_prefix, modem->vvm_type);
@@ -1489,10 +1490,11 @@ vvmd_subscribe_service (void)
       DBG ("Message: %s", message);
       vvmd_mm_create_sms (message);
     }
+  return G_SOURCE_REMOVE;
 }
 
-static void
-vvmd_unsubscribe_service (void)
+static gboolean
+vvmd_unsubscribe_service (gpointer user_data)
 {
   g_autofree char *message = NULL;
 
@@ -1505,13 +1507,13 @@ vvmd_unsubscribe_service (void)
   if (modem->modem_available == FALSE)
     {
       DBG ("Modem not available");
-      return;
+      return G_SOURCE_REMOVE;
     }
 
   if (modem->modem_ready == FALSE)
     {
       DBG ("Modem not ready");
-      return;
+      return G_SOURCE_REMOVE;
     }
 
   message = vvm_util_create_deactivate_sms (modem->carrier_prefix, modem->vvm_type);
@@ -1521,10 +1523,12 @@ vvmd_unsubscribe_service (void)
       DBG ("Message: %s", message);
       vvmd_mm_create_sms (message);
     }
+
+  return G_SOURCE_REMOVE;
 }
 
-static void
-vvmd_check_subscription_status (void)
+static gboolean
+vvmd_check_subscription_status (gpointer user_data)
 {
   g_autofree char *message = NULL;
   DBG ("Checking your carrier's VVM service");
@@ -1537,20 +1541,20 @@ vvmd_check_subscription_status (void)
           sleep (1);
         else {
             DBG ("Modem is disconnected, cannot attempt to provision vvm3");
-            return;
+            return G_SOURCE_REMOVE;
           }
       }
 
   if (modem->modem_available == FALSE)
     {
       DBG ("Modem not available");
-      return;
+      return G_SOURCE_REMOVE;
     }
 
   if (modem->modem_ready == FALSE)
     {
       DBG ("Modem not ready");
-      return;
+      return G_SOURCE_REMOVE;
     }
 
   message = vvm_util_create_status_sms (modem->carrier_prefix, modem->vvm_type);
@@ -1560,6 +1564,8 @@ vvmd_check_subscription_status (void)
       DBG ("Message: %s", message);
       vvmd_mm_create_sms (message);
     }
+
+  return G_SOURCE_REMOVE;
 }
 
 static void
@@ -1869,16 +1875,13 @@ vvmd_modem_available (void)
           modem->provision_status == VVM_PROVISION_STATUS_UNKNOWN ||
           modem->provision_status == VVM_PROVISION_STATUS_BLOCKED)
         {
-          DBG ("Checking status of carrier subscription");
-          vvmd_check_subscription_status ();
+          if (modem->enable_vvm)
+            g_timeout_add_seconds (5, vvmd_check_subscription_status, NULL);
         }
       else if (modem->provision_status == VVM_PROVISION_STATUS_PROVISIONED)
         {
           if (modem->enable_vvm)
-            {
-              DBG ("Subscribing to your carrier's VVM service");
-              vvmd_subscribe_service ();
-            }
+            g_timeout_add_seconds (5, vvmd_subscribe_service, NULL);
           else
             DBG ("VVM is disabled, not subscribing to your carrier's VVM service");
         }
@@ -1886,10 +1889,7 @@ vvmd_modem_available (void)
                modem->provision_status == VVM_PROVISION_STATUS_READY)
         {
           if (!modem->enable_vvm)
-            {
-              vvmd_unsubscribe_service ();
-              DBG ("Unsubscribing to your carrier's VVM service");
-            }
+            g_timeout_add_seconds (5, vvmd_unsubscribe_service, NULL);
           else
             DBG ("VVM is enabled and subscribed!");
         }
