@@ -82,6 +82,7 @@ struct vvm_service
   char *mailbox_voice_signature_length;
   char *mailbox_TUI_password_length;
   char *mailbox_vvm_type;
+  char *mailbox_ca_bundle;
   int mailbox_starttls;
   int mailbox_legacytls;
   vvm_service_bearer_handler_func_t bearer_handler;
@@ -482,6 +483,8 @@ activate_curl_structure (struct vvm_service *service)
 
   if (*service->mailbox_auth)
     curl_easy_setopt (service->curl, CURLOPT_LOGIN_OPTIONS, service->mailbox_auth);
+  if ((service->mailbox_ca_bundle != NULL) && (service->mailbox_ca_bundle[0] != '\0'))
+    curl_easy_setopt (service->curl, CURLOPT_CAINFO, service->mailbox_ca_bundle);
 }
 
 static void
@@ -535,6 +538,8 @@ vvm_service_test_vvm_imap_server (struct vvm_service *service,
 
   if (modem_iface)
     curl_easy_setopt (curl, CURLOPT_INTERFACE, service->mailbox_interface);
+  if ((service->mailbox_ca_bundle != NULL) && (service->mailbox_ca_bundle[0] != '\0'))
+    curl_easy_setopt (curl, CURLOPT_CAINFO, service->mailbox_ca_bundle);
 
   /*
    * This is testing various IMAP settings to see that works in this order:
@@ -595,6 +600,50 @@ vvm_service_test_vvm_imap_server (struct vvm_service *service,
       g_warning ("curl_easy_perform() failed: %s\n", curl_easy_strerror (res));
     }
 
+  //curl -v --login-options AUTH=+LOGIN imaps://$USERNAME:$PASSWORD@$HOSTNAME/
+  DBG ("Trying IMAP with SSL: Explicit +LOGIN Authentication");
+  g_free (mailbox_auth);
+  mailbox_auth = g_strdup ("AUTH=+LOGIN");
+  curl_easy_setopt (curl, CURLOPT_LOGIN_OPTIONS, mailbox_auth);
+
+  res = curl_easy_perform (curl);
+  // Try to guess if the server is using legacy ciphers
+  if (res == CURLE_SSL_CONNECT_ERROR)
+    {
+      DBG ("curl_easy_perform() failed: %s\n", curl_easy_strerror (res));
+      DBG ("Trying with legacy ciphers");
+      curl_easy_setopt (curl, CURLOPT_SSL_CIPHER_LIST, "ALL:@SECLEVEL=1");
+      res = curl_easy_perform (curl);
+      if (res == CURLE_OK)
+        {
+          service->mailbox_legacytls = TRUE;
+          g_key_file_set_boolean (service->settings, SETTINGS_GROUP_SERVICE,
+                                  "MailboxLegacyTLS", service->mailbox_legacytls);
+        }
+    }
+  if (res == CURLE_OK)
+    {
+      DBG ("Mailbox Activated!");
+      service->mailbox_active = TRUE;
+      service->mailbox_URI = URI;
+      service->mailbox_auth = mailbox_auth;
+
+      g_key_file_set_boolean (service->settings, SETTINGS_GROUP_SERVICE,
+                              "MailboxActive", service->mailbox_active);
+      g_key_file_set_string (service->settings, SETTINGS_GROUP_SERVICE,
+                             "MailboxURI", service->mailbox_URI);
+      g_key_file_set_string (service->settings, SETTINGS_GROUP_SERVICE,
+                             "MailboxAuth", service->mailbox_auth);
+      curl_easy_cleanup (curl);
+      return TRUE;
+    }
+  else {
+      // Reset authorized ciphers to the default value
+      curl_easy_setopt (curl, CURLOPT_SSL_CIPHER_LIST, "ALL");
+      g_warning ("curl_easy_perform() failed: %s\n", curl_easy_strerror (res));
+    }
+
+  //curl -v --login-options AUTH=PLAIN imaps://$USERNAME:$PASSWORD@$HOSTNAME/
   DBG ("Trying IMAP with SSL: Explicit PLAIN Authentication");
   g_free (mailbox_auth);
   mailbox_auth = g_strdup ("AUTH=PLAIN");
@@ -688,6 +737,8 @@ vvm_service_test_vvm_imap_server (struct vvm_service *service,
   // Set Username and Password
   curl_easy_setopt (curl, CURLOPT_USERNAME, service->mailbox_username);
   curl_easy_setopt (curl, CURLOPT_PASSWORD, service->mailbox_password);
+  if ((service->mailbox_ca_bundle != NULL) && (service->mailbox_ca_bundle[0] != '\0'))
+    curl_easy_setopt (curl, CURLOPT_CAINFO, service->mailbox_ca_bundle);
   //Do five second timeout
   curl_easy_setopt (curl, CURLOPT_TIMEOUT, 5L);
 
@@ -1465,8 +1516,8 @@ vvm_service_sync_vvm_imap_server (struct vvm_service *service)
   res = curl_easy_perform (service->curl);
   if (res == CURLE_OK)
     {
-      g_autofree char **tokens = NULL;
-      g_autofree char **lines = NULL;
+      g_auto(GStrv) tokens = NULL;
+      g_auto(GStrv) lines = NULL;
       g_autofree char *inbox_response;
       const char *inbox_response_search = NULL;
       g_autofree char *inbox_response_to_parse = NULL;
@@ -1498,14 +1549,11 @@ vvm_service_sync_vvm_imap_server (struct vvm_service *service)
       else
         inbox_response_to_parse = g_strdup (inbox_response);
 
-      /* Now we have " 1 2 3 4" */
+      /* Now we have " 1 2 3 4 10" */
       g_strstrip (inbox_response_to_parse);
-      /* Now we have "1 2 3 4" */
-      g_strreverse (inbox_response_to_parse);
-      g_debug ("inbox_response_to_parse:%s", inbox_response_to_parse);
-      /* Now we have "4 3 2 1" !*/
       tokens = g_strsplit (inbox_response_to_parse, " ", -1);
-      for (int i = 0; tokens[i] != NULL; i++)
+      /* Have to go in reverse since this the index changes as you delete voicemails */
+      for (unsigned int i = g_strv_length (tokens); i-- > 0; )
         {
           DBG ("Token: %s", tokens[i]);
           if (vvm_service_new_vvm (service, NULL, tokens[i], service->mailbox_vvm_type) == FALSE)
@@ -1724,6 +1772,17 @@ vvm_load_settings (struct vvm_service *service)
                               "AllowPlaintextConnection", service->allow_plaintext_connection);
       g_clear_error (&error);
     }
+  service->mailbox_ca_bundle = g_key_file_get_string (service->settings,
+                                                      SETTINGS_GROUP_SERVICE,
+                                                      "MailboxCABundle", &error);
+  if (error)
+    {
+      service->mailbox_ca_bundle = g_strdup ("");
+
+      g_key_file_set_string (service->settings, SETTINGS_GROUP_SERVICE,
+                             "MailboxCABundle", service->mailbox_ca_bundle);
+      g_clear_error (&error);
+    }
 }
 
 static void
@@ -1979,7 +2038,7 @@ load_message_from_store (const char       *service_id,
   vvm_msg->attachments = g_key_file_get_string (meta, "info", "Attachments", NULL);
   if (vvm_msg->attachments)
     {
-      g_autofree char **Attachment_list = NULL;
+      g_auto(GStrv) Attachment_list = NULL;
 
       Attachment_list = g_strsplit (vvm_msg->attachments, ";", -1);
       number_of_attachments = g_strv_length (Attachment_list);
@@ -2178,6 +2237,7 @@ vvm_service_unref (struct vvm_service *service)
       g_free (service->mailbox_voice_signature_length);
       g_free (service->mailbox_TUI_password_length);
       g_free (service->mailbox_vvm_type);
+      g_free (service->mailbox_ca_bundle);
       service->settings = NULL;
     }
 
@@ -2218,6 +2278,7 @@ vvm_service_unregister (struct vvm_service *service)
       g_free (service->mailbox_voice_signature_length);
       g_free (service->mailbox_TUI_password_length);
       g_free (service->mailbox_vvm_type);
+      g_free (service->mailbox_ca_bundle);
       service->settings = NULL;
     }
 
