@@ -104,7 +104,7 @@ static GMarkupParser vvm3_htmlline_parser = {
 char *
 vvm3_find_button (char *input)
 {
-  g_autofree char **inputLines = NULL;
+  g_auto(GStrv) inputLines = NULL;
 
   inputLines = g_strsplit_set (input, "\r\n", -1);
   if (inputLines == NULL)
@@ -185,9 +185,9 @@ vvm3_html_find_buttonUrl (GString *data)
 int
 validate_vvm3_host (const char *spgUrl)
 {
-  g_autofree char **known_hosts = NULL;
-  g_autofree char **host_and_port = NULL;
-  g_autofree char **host = NULL;
+  g_auto(GStrv) known_hosts = NULL;
+  g_auto(GStrv) host_and_port = NULL;
+  g_auto(GStrv) host = NULL;
   const char *stripped_url = NULL;
 
   if (!spgUrl || !*spgUrl)
@@ -253,15 +253,25 @@ vvm3_activation (const char *stripped_number,
     {
       CURLcode res = CURLE_OK;
       g_autofree char *spgUrl = NULL;
+      char *post_data = NULL;
 
+      post_data = curl_easy_escape (curl, gatewayRequestXml, strlen (gatewayRequestXml));
       curl_easy_setopt (curl, CURLOPT_URL, activate_url);
-      curl_easy_setopt (curl, CURLOPT_POSTFIELDS, curl_easy_escape (curl, gatewayRequestXml, strlen (gatewayRequestXml)));
+      curl_easy_setopt (curl, CURLOPT_POSTFIELDS, post_data);
       curl_easy_setopt (curl, CURLOPT_WRITEFUNCTION, vvm3_curl_writeback);
       curl_easy_setopt (curl, CURLOPT_WRITEDATA, data);
+
+      /* This doesn't happen very often and can fail, so let's leave debug on */
+      curl_easy_setopt (curl, CURLOPT_VERBOSE, 1L);
+
       /* only allow HTTP and HTTPS */
-      curl_easy_setopt (curl, CURLOPT_PROTOCOLS_STR, "http,https");
-      //curl_easy_setopt (curl, CURLOPT_PROTOCOLS, CURLPROTO_HTTP | CURLPROTO_HTTPS);
+      #ifdef HAVE_LIBCURL_CURLOPT_PROTOCOLS_STR
+        curl_easy_setopt (curl, CURLOPT_PROTOCOLS_STR, "http,https");
+      #else
+        curl_easy_setopt (curl, CURLOPT_PROTOCOLS, CURLPROTO_HTTP | CURLPROTO_HTTPS);
+      #endif
       res = curl_easy_perform (curl);
+      curl_free(post_data);
 
       if (res != CURLE_OK)
         {
@@ -296,9 +306,16 @@ vvm3_activation (const char *stripped_number,
           curl_easy_setopt (curl, CURLOPT_WRITEDATA, data);
           curl_easy_setopt (curl, CURLOPT_COOKIEFILE, "");
           curl_easy_setopt (curl, CURLOPT_POST, 1);
+
+          /* This doesn't happen very often and can fail, so let's leave debug on */
+          curl_easy_setopt (curl, CURLOPT_VERBOSE, 1L);
+
           /* only allow HTTP and HTTPS */
-          curl_easy_setopt (curl, CURLOPT_PROTOCOLS_STR, "http,https");
-          //curl_easy_setopt (curl, CURLOPT_PROTOCOLS, CURLPROTO_HTTP | CURLPROTO_HTTPS);
+          #ifdef HAVE_LIBCURL_CURLOPT_PROTOCOLS_STR
+            curl_easy_setopt (curl, CURLOPT_PROTOCOLS_STR, "http,https");
+          #else
+            curl_easy_setopt (curl, CURLOPT_PROTOCOLS, CURLPROTO_HTTP | CURLPROTO_HTTPS);
+          #endif
 
           //Form a special request based on constants derived from AOSP
           requestParams = g_strdup_printf ("%s=%s&%s=%s&%s=%s&%s=%s&%s=%s",
