@@ -71,11 +71,17 @@ vvm_util_create_att_usa_status_sms (const char *carrier_prefix)
   // carrier_prefix => put your number with no spaces
   //                 (i.e if your number is (999) 555-1123, use 9995551123
 }
+
+/*
+ * 'STATE?' works for France Free Mobile, but not Vodafone au. However,
+ * 'STATE' works for both. As of now, just changed all of them to 'STATE'
+ * and we can work out other issues if they come up later
+ */
 static char
 *
-vvm_util_create_freemobile_fr_status_sms (const char *carrier_prefix)
+vvm_util_create_ios_status_sms (const char *carrier_prefix)
 {
-  return g_strdup_printf ("STATE?");
+  return g_strdup_printf ("STATE");
 }
 
 char *
@@ -100,6 +106,8 @@ vvm_util_create_deactivate_sms (const char *carrier_prefix,
     g_critical ("I do not know how to unsubscribe from AT&T USA!");
   else if (g_strcmp0 (vvm_type, "FreeMobileProprietary") == 0)
     g_critical ("I do not know how to unsubscribe from Free Mobile!");
+  else if (g_strcmp0 (vvm_type, "ios") == 0)
+    g_critical ("I do not know how to unsubscribe from ios!");
   else if (g_strcmp0 (vvm_type, "vvm3") == 0)
     g_critical ("There is no way to unsubscribe from vvm3!");
   else
@@ -129,7 +137,9 @@ vvm_util_create_activate_sms (const char *carrier_prefix,
   else if (g_strcmp0 (vvm_type, "AT&TUSAProprietary") == 0)
     return vvm_util_create_att_usa_status_sms (carrier_prefix);
   else if (g_strcmp0 (vvm_type, "FreeMobileProprietary") == 0)
-    return vvm_util_create_freemobile_fr_status_sms (carrier_prefix);
+    return vvm_util_create_ios_status_sms (carrier_prefix);
+  else if (g_strcmp0 (vvm_type, "ios") == 0)
+    return vvm_util_create_ios_status_sms (carrier_prefix);
   else if (g_strcmp0 (vvm_type, "vvm3") == 0)
     return g_strdup_printf ("STATUS");
   else
@@ -160,7 +170,9 @@ vvm_util_create_status_sms (const char *carrier_prefix,
   else if (g_strcmp0 (vvm_type, "AT&TUSAProprietary") == 0)
     return vvm_util_create_att_usa_status_sms (carrier_prefix);
   else if (g_strcmp0 (vvm_type, "FreeMobileProprietary") == 0)
-    return vvm_util_create_freemobile_fr_status_sms (carrier_prefix);
+    return vvm_util_create_ios_status_sms (carrier_prefix);
+  else if (g_strcmp0 (vvm_type, "ios") == 0)
+    return vvm_util_create_ios_status_sms (carrier_prefix);
   else if (g_strcmp0 (vvm_type, "vvm3") == 0)
     return g_strdup_printf ("STATUS");
   else
@@ -216,8 +228,8 @@ vvm_util_parse_att_usa_sms_message_type (const char *message,
 
 
 static int
-vvm_util_parse_freemobile_fr_sms_message_type (const char *message,
-                                               const char *carrier_prefix)
+vvm_util_parse_ios_sms_message_type (const char *message,
+                                     const char *carrier_prefix)
 {
   if (g_str_has_prefix (message, "STATE?state="))
     return SMS_MESSAGE_STATUS;
@@ -242,7 +254,9 @@ vvm_util_parse_sms_message_type (const char *message,
   else if (g_strcmp0 (vvm_type, "AT&TUSAProprietary") == 0)
     sms_message_type = vvm_util_parse_att_usa_sms_message_type (message, carrier_prefix);
   else if (g_strcmp0 (vvm_type, "FreeMobileProprietary") == 0)
-    sms_message_type = vvm_util_parse_freemobile_fr_sms_message_type (message, carrier_prefix);
+    sms_message_type = vvm_util_parse_ios_sms_message_type (message, carrier_prefix);
+  else if (g_strcmp0 (vvm_type, "ios") == 0)
+    sms_message_type = vvm_util_parse_ios_sms_message_type (message, carrier_prefix);
   else {
       g_critical ("Unknown VVM type!");
       sms_message_type = SMS_MESSAGE_OTHER;
@@ -336,8 +350,8 @@ vvm_util_parse_sync_att_usa_sms_message (const char                 *message,
 }
 
 void
-vvm_util_parse_sync_freemobile_fr_sms_message (const char                 *message,
-                                               struct sms_control_message *sms_msg)
+vvm_util_parse_sync_ios_sms_message (const char                 *message,
+                                     struct sms_control_message *sms_msg)
 {
   DBG ("FreeMobile Sync message contain only the number of new messages.");
   sms_msg->sync_status_reason = SYNC_SMS_MAILBOX_UPDATE;
@@ -358,7 +372,9 @@ vvm_util_parse_sync_sms_message (const char                 *message,
   else if (g_strcmp0 (vvm_type, "AT&TUSAProprietary") == 0)
     vvm_util_parse_sync_att_usa_sms_message (message, sms_msg);
   else if (g_strcmp0 (vvm_type, "FreeMobileProprietary") == 0)
-    vvm_util_parse_sync_freemobile_fr_sms_message (message, sms_msg);
+    vvm_util_parse_sync_ios_sms_message (message, sms_msg);
+  else if (g_strcmp0 (vvm_type, "ios") == 0)
+    vvm_util_parse_sync_ios_sms_message (message, sms_msg);
   else
     g_critical ("Unknown VVM type!");
 }
@@ -590,8 +606,16 @@ vvm_util_parse_status_ios_sms_message (const char                 *message,
             }
           else if (g_strcmp0 (single_setting[0], "name") == 0)
             {
-              g_autofree gchar **name_parts = NULL;
               sms_msg->mailbox_username = g_strdup (single_setting[1]);
+              if (strstr (sms_msg->mailbox_username, "CMSGROUP"))
+                {
+                  char **name_parts = NULL;
+                  name_parts = g_strsplit (sms_msg->mailbox_username, ":", -1);
+
+                  g_clear_pointer (&sms_msg->mailbox_username, g_free);
+                  sms_msg->mailbox_username = g_strdup (name_parts[1]);
+                  g_strfreev (name_parts);
+                }
             }
           else
             //I have no idea what these settings are
@@ -611,14 +635,7 @@ vvm_util_parse_status_att_usa_sms_message (const char                 *message,
 
   if (g_str_has_prefix (message, "STATE?state="))
     {
-      g_autofree gchar **name_parts = NULL;
-
       vvm_util_parse_status_ios_sms_message (message, sms_msg);
-
-      name_parts = g_strsplit (sms_msg->mailbox_username, ":", -1);
-
-      g_clear_pointer (&sms_msg->mailbox_username, g_free);
-      sms_msg->mailbox_username = g_strdup (name_parts[1]);
     }
   else {
       if (g_str_has_prefix (message, "GET?AD="))
@@ -708,6 +725,8 @@ vvm_util_parse_status_sms_message (const char                 *message,
     vvm_util_parse_status_att_usa_sms_message (message, sms_msg);
   else if (g_strcmp0 (vvm_type, "FreeMobileProprietary") == 0)
     vvm_util_parse_status_ios_sms_message (message, sms_msg);
+  else if (g_strcmp0 (vvm_type, "ios") == 0)
+    vvm_util_parse_status_ios_sms_message (message, sms_msg);
   else
     g_critical ("Unknown VVM type!");
 }
@@ -792,7 +811,7 @@ vvm_util_decode_vvm_single_email_attachment (const char *attachment,
                                              const char *folderpath)
 {
   DBG ("Decoding Attachment");
-  g_autofree char **lines = NULL;
+  g_auto(GStrv) lines = NULL;
   g_autofree char *contentencoding = NULL;
   g_autofree char *contenttype = NULL;
   g_autofree char *duration = NULL;
@@ -802,14 +821,14 @@ vvm_util_decode_vvm_single_email_attachment (const char *attachment,
   int found_attachment = FALSE;
   int base64_encoded;
 
-  g_autofree char **attribute_parse = NULL;
+  g_auto(GStrv) attribute_parse = NULL;
   g_autofree char *filename = NULL;
 
   lines = g_strsplit_set (attachment, "\r\n", -1);
   //Decode Attachment headers first
   for (int i = 0; lines[i] != NULL; i++)
     {
-      g_autofree char **header = NULL;
+      g_auto(GStrv) header = NULL;
       if (strlen (lines[i]) < 1)
         continue;
       header = g_strsplit_set (lines[i], ":", 2);
@@ -859,7 +878,7 @@ vvm_util_decode_vvm_single_email_attachment (const char *attachment,
   for (int i = 0; attribute_parse[i] != NULL; i++)
     if (g_str_match_string ("filename", attribute_parse[i], TRUE))
       {
-        g_autofree char **filename_parse = NULL;
+        g_auto(GStrv) filename_parse = NULL;
         filename_parse = g_strsplit_set (attribute_parse[i], "=", 2);
         filename = g_strdup (filename_parse[1]);
         g_strdelimit (filename, "\"", ' ');
@@ -934,9 +953,9 @@ static int
 vvm_util_decode_vvm_email_multipart_mixed (struct voicemail *vvm_msg,
                                            const char       *folderpath)
 {
-  g_autofree char **tokens = NULL;
-  g_autofree char **boundary = NULL;
-  g_autofree char **email_attachments = NULL;
+  g_auto(GStrv) tokens = NULL;
+  g_auto(GStrv) boundary = NULL;
+  g_auto(GStrv) email_attachments = NULL;
 
   DBG ("Decoding message of content type: %s", vvm_msg->content_type);
 
