@@ -63,19 +63,37 @@ test_sms (gconstpointer data)
   //This is an ready status SMS
   const char att_usa_status_sms_0[] = "vvm.mobile.att.net:5400?f=0&v=1010&m=1235550000&p=WFRRXlpTVVVfWTAwMDAw&P=WFRRXlpTVVVfWTAwMDAw&S=I&s=5433&i=143/993&t=4:1235550000:A:CMSGROUP024121413";
 
-  //This is an unprovisioned status SMS
+  //This is from AT&T, but is a iOS status message
   //pw looks to be a first password? And the last 7 digits of "name"
-  const char att_usa_status_sms_1[] = "STATE?state=NewAccount;server=vvm.mobile.att.net;port=143;name=4:1235550000:A:CMSGROUP0241238:ms06:NAT:31413;pw=5550000";
+  const char ios_status_sms_0[] = "STATE?state=NewAccount;server=vvm.mobile.att.net;port=143;name=4:1235550000:A:CMSGROUP0241238:ms06:NAT:31413;pw=5550000";
 
   //FreeMobile
+  // These are really iOS messages too
   //This is a provisioned status SMS
-  const char freemobile_fr_status_sms_0[] = "STATE?state=NewAccount;name=1234567;server=vvm.proxad.net;port=993;pw=PASSWORD";
+  const char ios_status_sms_1[] = "STATE?state=NewAccount;name=1234567;server=vvm.proxad.net;port=993;pw=PASSWORD";
   //This is a provisioned status SMS
-  const char freemobile_fr_status_sms_1[] = "STATE?state=Active;server=vvm.proxad.net;port=993;pw=PASSWORD;name=1234567";
+  const char ios_status_sms_2[] = "STATE?state=Active;server=vvm.proxad.net;port=993;pw=PASSWORD;name=1234567";
   //This is an unprovisioned status SMS
-  const char freemobile_fr_status_sms_2[] = "STATE?state=NotAvailable";
+  const char ios_status_sms_3[] = "STATE?state=NotAvailable";
   //This is a sync SMS
-  const char freemobile_fr_sync_sms_0[] = "MBOXUPDATE?m=1";
+  const char ios_sync_sms_0[] = "MBOXUPDATE?m=1";
+
+  //From vodafone au
+  // These are really iOS messages too
+  const char ios_status_sms_4[] = "STATE?state=NewAccount;name=username;server=prodvvm.vodafone.com.au;port=993;pw=pass";
+  const char ios_sync_sms_1[] = "MBOXUPDATE?m=17;server=prodvvm.vodafone.com.au;port=993;name=username;pw=pass";
+
+
+  /*
+   * 'STATE?' works for France Free Mobile, but not Vodafone au. However,
+   * 'STATE' works for both. As of now, just changed all of them to 'STATE'
+   * and we can work out other issues if they come up later
+   */
+  /*
+   * If one sent `STATE?' to vodafone au, they got back the following. Keep it around for now
+   * in case it is useful later
+   */
+  //const char *ios_unrecognised_command_state_0 = "UNRECOGNISED?cmd=STATE?";
 
   sms_msg = g_try_new0 (struct sms_control_message, 1);
   if (sms_msg == NULL)
@@ -335,8 +353,8 @@ test_sms (gconstpointer data)
       g_assert (FALSE);
     }
 
-  g_assert (vvm_util_parse_sms_message_type (att_usa_status_sms_1, "1235550000", "AT&TUSAProprietary") == SMS_MESSAGE_STATUS);
-  vvm_util_parse_status_sms_message (att_usa_status_sms_1, sms_msg, "AT&TUSAProprietary");
+  g_assert (vvm_util_parse_sms_message_type (ios_status_sms_0, "1235550000", "AT&TUSAProprietary") == SMS_MESSAGE_STATUS);
+  vvm_util_parse_status_sms_message (ios_status_sms_0, sms_msg, "AT&TUSAProprietary");
 
   g_assert (sms_msg->provision_status == VVM_PROVISION_STATUS_NEW);
 
@@ -348,6 +366,7 @@ test_sms (gconstpointer data)
 
   g_assert (g_strcmp0 (sms_msg->mailbox_password, "5550000") == 0);
 
+  //This is only present for AT&T
   g_assert (g_strcmp0 (sms_msg->TUI_password_length, "7-15") == 0);
 
   vvm_util_delete_status_message (sms_msg);
@@ -360,8 +379,8 @@ test_sms (gconstpointer data)
       g_assert (FALSE);
     }
 
-  g_assert (vvm_util_parse_sms_message_type (freemobile_fr_status_sms_0, "//VVM", "FreeMobileProprietary") == SMS_MESSAGE_STATUS);
-  vvm_util_parse_status_sms_message (freemobile_fr_status_sms_0, sms_msg, "FreeMobileProprietary");
+  g_assert (vvm_util_parse_sms_message_type (ios_status_sms_1, "//VVM", "FreeMobileProprietary") == SMS_MESSAGE_STATUS);
+  vvm_util_parse_status_sms_message (ios_status_sms_1, sms_msg, "FreeMobileProprietary");
   //st
   g_assert (sms_msg->provision_status == VVM_PROVISION_STATUS_NEW);
   //server
@@ -382,8 +401,8 @@ test_sms (gconstpointer data)
       g_assert (FALSE);
     }
 
-  g_assert (vvm_util_parse_sms_message_type (freemobile_fr_status_sms_1, "//VVM", "FreeMobileProprietary") == SMS_MESSAGE_STATUS);
-  vvm_util_parse_status_sms_message (freemobile_fr_status_sms_1, sms_msg, "FreeMobileProprietary");
+  g_assert (vvm_util_parse_sms_message_type (ios_status_sms_2, "//VVM", "FreeMobileProprietary") == SMS_MESSAGE_STATUS);
+  vvm_util_parse_status_sms_message (ios_status_sms_2, sms_msg, "FreeMobileProprietary");
   //st
   g_assert (sms_msg->provision_status == VVM_PROVISION_STATUS_READY);
   //server
@@ -404,8 +423,8 @@ test_sms (gconstpointer data)
       g_assert (FALSE);
     }
 
-  g_assert (vvm_util_parse_sms_message_type (freemobile_fr_status_sms_2, "//VVM", "FreeMobileProprietary") == SMS_MESSAGE_STATUS);
-  vvm_util_parse_status_sms_message (freemobile_fr_status_sms_2, sms_msg, "FreeMobileProprietary");
+  g_assert (vvm_util_parse_sms_message_type (ios_status_sms_3, "//VVM", "FreeMobileProprietary") == SMS_MESSAGE_STATUS);
+  vvm_util_parse_status_sms_message (ios_status_sms_3, sms_msg, "FreeMobileProprietary");
   //st
   g_assert (sms_msg->provision_status == VVM_PROVISION_STATUS_BLOCKED);
 
@@ -418,8 +437,139 @@ test_sms (gconstpointer data)
       g_assert (FALSE);
     }
 
-  g_assert (vvm_util_parse_sms_message_type (freemobile_fr_sync_sms_0, "//VVM", "FreeMobileProprietary") == SMS_MESSAGE_SYNC);
-  vvm_util_parse_sync_sms_message (freemobile_fr_status_sms_0, sms_msg, "FreeMobileProprietary");
+  g_assert (vvm_util_parse_sms_message_type (ios_sync_sms_0, "//VVM", "FreeMobileProprietary") == SMS_MESSAGE_SYNC);
+  vvm_util_parse_sync_sms_message (ios_sync_sms_0, sms_msg, "FreeMobileProprietary");
+  //Mailbox Update
+  g_assert (sms_msg->sync_status_reason == SYNC_SMS_MAILBOX_UPDATE);
+
+  vvm_util_delete_status_message (sms_msg);
+
+  //ios message
+  sms_msg = g_try_new0 (struct sms_control_message, 1);
+  if (sms_msg == NULL)
+    {
+      g_critical ("Could not allocate space for SMS SYNC Message!");
+      g_assert (FALSE);
+    }
+
+  g_assert (vvm_util_parse_sms_message_type (ios_status_sms_0, "//vvm", "ios") == SMS_MESSAGE_STATUS);
+  vvm_util_parse_status_sms_message (ios_status_sms_0, sms_msg, "ios");
+
+  g_assert (sms_msg->provision_status == VVM_PROVISION_STATUS_NEW);
+
+  g_assert (g_strcmp0 (sms_msg->mailbox_hostname, "vvm.mobile.att.net") == 0);
+
+  g_assert (g_strcmp0 (sms_msg->mailbox_port, "143") == 0);
+
+  g_assert_cmpstr (sms_msg->mailbox_username, == , "1235550000");
+
+  g_assert (g_strcmp0 (sms_msg->mailbox_password, "5550000") == 0);
+
+  vvm_util_delete_status_message (sms_msg);
+
+  sms_msg = g_try_new0 (struct sms_control_message, 1);
+  if (sms_msg == NULL)
+    {
+      g_critical ("Could not allocate space for SMS SYNC Message!");
+      g_assert (FALSE);
+    }
+
+  g_assert (vvm_util_parse_sms_message_type (ios_status_sms_1, "//VVM", "ios") == SMS_MESSAGE_STATUS);
+  vvm_util_parse_status_sms_message (ios_status_sms_1, sms_msg, "ios");
+  //st
+  g_assert (sms_msg->provision_status == VVM_PROVISION_STATUS_NEW);
+  //server
+  g_assert (g_strcmp0 (sms_msg->mailbox_hostname, "vvm.proxad.net") == 0);
+  //port
+  g_assert (g_strcmp0 (sms_msg->mailbox_port, "993") == 0);
+  //name
+  g_assert (g_strcmp0 (sms_msg->mailbox_username, "1234567") == 0);
+  //password
+  g_assert (g_strcmp0 (sms_msg->mailbox_password, "PASSWORD") == 0);
+
+  vvm_util_delete_status_message (sms_msg);
+
+  sms_msg = g_try_new0 (struct sms_control_message, 1);
+  if (sms_msg == NULL)
+    {
+      g_critical ("Could not allocate space for SMS SYNC Message!");
+      g_assert (FALSE);
+    }
+
+  g_assert (vvm_util_parse_sms_message_type (ios_status_sms_2, "//VVM", "ios") == SMS_MESSAGE_STATUS);
+  vvm_util_parse_status_sms_message (ios_status_sms_2, sms_msg, "ios");
+  //st
+  g_assert (sms_msg->provision_status == VVM_PROVISION_STATUS_READY);
+  //server
+  g_assert (g_strcmp0 (sms_msg->mailbox_hostname, "vvm.proxad.net") == 0);
+  //port
+  g_assert (g_strcmp0 (sms_msg->mailbox_port, "993") == 0);
+  //name
+  g_assert (g_strcmp0 (sms_msg->mailbox_username, "1234567") == 0);
+  //password
+  g_assert (g_strcmp0 (sms_msg->mailbox_password, "PASSWORD") == 0);
+
+  vvm_util_delete_status_message (sms_msg);
+
+  sms_msg = g_try_new0 (struct sms_control_message, 1);
+  if (sms_msg == NULL)
+    {
+      g_critical ("Could not allocate space for SMS SYNC Message!");
+      g_assert (FALSE);
+    }
+
+  g_assert (vvm_util_parse_sms_message_type (ios_status_sms_3, "//VVM", "ios") == SMS_MESSAGE_STATUS);
+  vvm_util_parse_status_sms_message (ios_status_sms_3, sms_msg, "ios");
+  //st
+  g_assert (sms_msg->provision_status == VVM_PROVISION_STATUS_BLOCKED);
+
+  vvm_util_delete_status_message (sms_msg);
+
+  sms_msg = g_try_new0 (struct sms_control_message, 1);
+  if (sms_msg == NULL)
+    {
+      g_critical ("Could not allocate space for SMS SYNC Message!");
+      g_assert (FALSE);
+    }
+
+  g_assert (vvm_util_parse_sms_message_type (ios_status_sms_4, "//vvm", "ios") == SMS_MESSAGE_STATUS);
+  vvm_util_parse_status_sms_message (ios_status_sms_4, sms_msg, "ios");
+
+  g_assert (sms_msg->provision_status == VVM_PROVISION_STATUS_NEW);
+
+  g_assert (g_strcmp0 (sms_msg->mailbox_hostname, "prodvvm.vodafone.com.au") == 0);
+
+  g_assert (g_strcmp0 (sms_msg->mailbox_port, "993") == 0);
+
+  g_assert_cmpstr (sms_msg->mailbox_username, == , "username");
+
+  g_assert (g_strcmp0 (sms_msg->mailbox_password, "pass") == 0);
+
+  vvm_util_delete_status_message (sms_msg);
+
+  sms_msg = g_try_new0 (struct sms_control_message, 1);
+  if (sms_msg == NULL)
+    {
+      g_critical ("Could not allocate space for SMS SYNC Message!");
+      g_assert (FALSE);
+    }
+
+  g_assert (vvm_util_parse_sms_message_type (ios_sync_sms_0, "//VVM", "ios") == SMS_MESSAGE_SYNC);
+  vvm_util_parse_sync_sms_message (ios_sync_sms_0, sms_msg, "ios");
+  //Mailbox Update
+  g_assert (sms_msg->sync_status_reason == SYNC_SMS_MAILBOX_UPDATE);
+
+  vvm_util_delete_status_message (sms_msg);
+
+  sms_msg = g_try_new0 (struct sms_control_message, 1);
+  if (sms_msg == NULL)
+    {
+      g_critical ("Could not allocate space for SMS SYNC Message!");
+      g_assert (FALSE);
+    }
+
+  g_assert (vvm_util_parse_sms_message_type (ios_sync_sms_1, "//VVM", "ios") == SMS_MESSAGE_SYNC);
+  vvm_util_parse_sync_sms_message (ios_sync_sms_1, sms_msg, "ios");
   //Mailbox Update
   g_assert (sms_msg->sync_status_reason == SYNC_SMS_MAILBOX_UPDATE);
 
